@@ -10,7 +10,7 @@ use Net::SSLLabs::Host();
 use Net::SSLLabs::Endpoint();
 use Net::SSLLabs::StatusCodes();
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub new {
     my ($class) = @_;
@@ -79,9 +79,12 @@ sub _sort_ssllabs_params {
     elsif ( $b eq 'host' ) {
         return 1;
     }
-    elsif ( $a eq 's' ) {
+    if ( $a eq 's' ) {
         return -1;
     }
+    elsif ( $b eq 's' ) {
+        return 1;
+    }
     else {
         return $a cmp $b;
     }
@@ -129,7 +132,7 @@ Net::SSLLabs - Analyze the configuration of any SSL web server on the public Int
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
